Module bundle

Module bundle 

Structs

BundleArtifact
Represents an artifact within a bundle (WASM, ABI, migration)
BundleInterfaces
Declarative interfaces (intents) implemented or required by the application
BundleLinks
External links for the application
BundleManifest
Bundle manifest describing the contents of a bundle archive
BundleMetadata
Display metadata for the application
BundleSignature
Cryptographic signature of the manifest
ManifestVerification
Result of manifest signature verification.

Functions

canonicalize_manifest
Canonicalizes a manifest JSON value using RFC 8785 (JCS).
compute_bundle_hash
Computes the bundle hash from canonical manifest bytes.
compute_signing_payload
Computes the signing payload from canonical manifest bytes.
decode_public_key
Decodes a base64url (no padding) encoded public key.
decode_signature
Decodes a base64url (no padding) encoded signature.
derive_signer_id_did_key
Derives a did:key signerId from an Ed25519 public key.
format_bundle_hash
Formats a bundle hash as a lowercase hex string.
sign_manifest_json
Signs a manifest JSON value and adds the signature field.
verify_ed25519
Verifies an Ed25519 signature over a message.
verify_manifest_signature
Verifies a bundle manifest signature.