pub enum PushResult {
Added,
Duplicate,
Evicted([u8; 32]),
DroppedZeroCapacity([u8; 32]),
}Expand description
Result of pushing a delta to the buffer.
Provides clear semantics about what happened to both the incoming delta and any evicted delta.
Variants
Added
Delta was added to the buffer without eviction.
Duplicate
Delta was a duplicate (already in buffer) - no action taken.
Evicted([u8; 32])
Delta was added, but oldest delta was evicted due to capacity. Contains the ID of the evicted delta.
DroppedZeroCapacity([u8; 32])
Delta was dropped immediately (zero capacity buffer). Contains the ID of the dropped delta.
Implementations
Sourceimpl PushResult
impl PushResult