pub struct RemovePendingSpecializedNodeInvite {
pub nonce: [u8; 32],
}Expand description
Request to remove a pending specialized node invite from the node’s state. Used to clean up if broadcast fails after registration.
Fields
nonce: [u8; 32]The nonce to remove