pub struct LevelWiseResponse {
pub level: usize,
pub nodes: Vec<LevelNode>,
pub has_more_levels: bool,
}Expand description
Response containing nodes at a specific level.
Fields
level: usizeLevel these nodes are at.
nodes: Vec<LevelNode>Nodes at this level.
Limited to MAX_NODES_PER_LEVEL entries. Use is_valid() to check
bounds after deserialization from untrusted sources.
has_more_levels: boolWhether there are more levels below this one.
Implementations
Sourceimpl LevelWiseResponse
impl LevelWiseResponse
Sourcepub fn new(level: usize, nodes: Vec<LevelNode>, has_more_levels: bool) -> Self
pub fn new(level: usize, nodes: Vec<LevelNode>, has_more_levels: bool) -> Self
Create a response with nodes.
Sourcepub fn node_count(&self) -> usize
pub fn node_count(&self) -> usize
Number of nodes at this level.
Sourcepub fn leaves(&self) -> impl Iterator<Item = &LevelNode>
pub fn leaves(&self) -> impl Iterator<Item = &LevelNode>
Get an iterator over leaf nodes at this level.
Sourcepub fn internal_nodes(&self) -> impl Iterator<Item = &LevelNode>
pub fn internal_nodes(&self) -> impl Iterator<Item = &LevelNode>
Get an iterator over internal nodes at this level.
Sourcepub fn internal_node_ids(&self) -> Vec<[u8; 32]>
pub fn internal_node_ids(&self) -> Vec<[u8; 32]>
Get IDs of all internal nodes (for next level request).