select_protocol_with_fallback

Function select_protocol_with_fallback 

pub fn select_protocol_with_fallback(
    local: &SyncHandshake,
    remote: &SyncHandshake,
    remote_capabilities: &SyncCapabilities,
) -> ProtocolSelection
Select protocol with fallback if preferred is not supported.

Tries the preferred protocol first, then falls back through the decision table until a mutually supported protocol is found.