Structs
- Bundle
Artifact - Represents an artifact within a bundle (WASM, ABI, migration)
- Bundle
Interfaces - Declarative interfaces (intents) implemented or required by the application
- Bundle
Links - External links for the application
- Bundle
Manifest - Bundle manifest describing the contents of a bundle archive
- Bundle
Metadata - Display metadata for the application
- Bundle
Signature - Cryptographic signature of the manifest
- Manifest
Verification - Result of manifest signature verification.
Functions
- canonicalize_
manifest - Canonicalizes a manifest JSON value using RFC 8785 (JCS).
- compute_
bundle_ hash - Computes the bundle hash from canonical manifest bytes.
- compute_
signing_ payload - Computes the signing payload from canonical manifest bytes.
- decode_
public_ key - Decodes a base64url (no padding) encoded public key.
- decode_
signature - Decodes a base64url (no padding) encoded signature.
- derive_
signer_ id_ did_ key - Derives a did:key signerId from an Ed25519 public key.
- format_
bundle_ hash - Formats a bundle hash as a lowercase hex string.
- sign_
manifest_ json - Signs a manifest JSON value and adds the signature field.
- verify_
ed25519 - Verifies an Ed25519 signature over a message.
- verify_
manifest_ signature - Verifies a bundle manifest signature.