pub struct BundleManifest {
pub version: String,
pub package: String,
pub app_version: String,
pub signer_id: Option<String>,
pub min_runtime_version: String,
pub metadata: Option<BundleMetadata>,
pub interfaces: Option<BundleInterfaces>,
pub wasm: Option<BundleArtifact>,
pub abi: Option<BundleArtifact>,
pub migrations: Vec<BundleArtifact>,
pub links: Option<BundleLinks>,
pub signature: Option<BundleSignature>,
}Expand description
Bundle manifest describing the contents of a bundle archive
Fields
version: Stringpackage: Stringapp_version: Stringsigner_id: Option<String>The signerId (did:key) derived from the signing public key.
This field is required for all bundle manifests. Both signer_id and signature
must be present for bundle installation. The signer_id must match the signerId derived
from the signature’s public key during verification.
The field is Option<String> at the type level for deserialization flexibility, but
verify_manifest_signature will reject manifests where this field is None.
min_runtime_version: StringMinimum required runtime version (semver).
metadata: Option<BundleMetadata>interfaces: Option<BundleInterfaces>wasm: Option<BundleArtifact>abi: Option<BundleArtifact>migrations: Vec<BundleArtifact>links: Option<BundleLinks>signature: Option<BundleSignature>Trait Implementations
Sourceimpl Clone for BundleManifest
impl Clone for BundleManifest
Sourcefn clone(&self) -> BundleManifest
fn clone(&self) -> BundleManifest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BundleManifest
impl Debug for BundleManifest
Sourceimpl<'de> Deserialize<'de> for BundleManifest
impl<'de> Deserialize<'de> for BundleManifest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more