PushResult

Enum PushResult 

pub enum PushResult {
    Added,
    Duplicate,
    Evicted([u8; 32]),
    DroppedZeroCapacity([u8; 32]),
}
Result of pushing a delta to the buffer.

Provides clear semantics about what happened to both the incoming delta and any evicted delta.

Variants



Added

Delta was added to the buffer without eviction.



Duplicate

Delta was a duplicate (already in buffer) - no action taken.



Evicted([u8; 32])

Delta was added, but oldest delta was evicted due to capacity. Contains the ID of the evicted delta.



DroppedZeroCapacity([u8; 32])

Delta was dropped immediately (zero capacity buffer). Contains the ID of the dropped delta.

Implementations

Source

impl PushResult

pub fn was_added(&self) -> bool

Returns true if the delta was successfully added to the buffer.

pub fn had_data_loss(&self) -> bool

Returns true if any delta was lost (evicted or dropped).

pub fn lost_delta_id(&self) -> Option<[u8; 32]>

Returns the ID of the lost delta, if any.