pub fn select_protocol_with_fallback(
local: &SyncHandshake,
remote: &SyncHandshake,
remote_capabilities: &SyncCapabilities,
) -> ProtocolSelectionExpand description
Select protocol with fallback if preferred is not supported.
Tries the preferred protocol first, then falls back through the decision table until a mutually supported protocol is found.