#[non_exhaustive]pub enum BroadcastMessage<'a> {
StateDelta {
context_id: ContextId,
author_id: PublicKey,
delta_id: [u8; 32],
parent_ids: Vec<[u8; 32]>,
hlc: HybridTimestamp,
root_hash: Hash,
artifact: Cow<'a, [u8]>,
nonce: Nonce,
events: Option<Cow<'a, [u8]>>,
},
HashHeartbeat {
context_id: ContextId,
root_hash: Hash,
dag_heads: Vec<[u8; 32]>,
},
SpecializedNodeDiscovery {
nonce: [u8; 32],
node_type: SpecializedNodeType,
},
SpecializedNodeJoinConfirmation {
nonce: [u8; 32],
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
StateDelta
HashHeartbeat
Hash heartbeat for divergence detection
Periodically broadcast by nodes to allow peers to detect silent divergence. If a peer has a different hash for the same DAG heads, it indicates a problem.
Fields
SpecializedNodeDiscovery
Specialized node discovery request
Broadcast by a node to discover and invite specialized nodes (e.g., read-only TEE nodes). Specialized nodes receiving this will respond via request-response protocol to the message source (available from gossipsub message).
Note: context_id is NOT included - it’s tracked internally by the requesting node using the nonce as the lookup key.
Fields
node_type: SpecializedNodeTypeType of specialized node being invited
SpecializedNodeJoinConfirmation
Confirmation that a specialized node has joined a context
Broadcast by specialized nodes on the context topic after successfully joining. The inviting node receives this and removes the pending invite entry.